@@ -11,23 +11,26 @@ AbstractCommentListModel::AbstractCommentListModel(QObject *parent) :
     m_loaderPressedRow(-1)
   #endif
 {
-    QHash<int, QByteArray> roles;
-    roles[IdRole] = "id";
-    roles[BodyRole] = "body";
-    roles[ArtistRole] = "artist";
-    roles[ArtistIdRole] = "artistId";
-    roles[ArtistAvatarUrlRole] = "artistAvatarUrl";
-    roles[DateRole] = "date";
-    roles[VideoIdRole] = "videoId";
-    roles[ReplyIdRole] = "replyId";
-    roles[IndentRole] = "indent";
-    roles[LoadingRole] = "loading";
+    m_roleNames[IdRole] = "id";
+    m_roleNames[BodyRole] = "body";
+    m_roleNames[ArtistRole] = "artist";
+    m_roleNames[ArtistIdRole] = "artistId";
+    m_roleNames[ArtistAvatarUrlRole] = "artistAvatarUrl";
+    m_roleNames[DateRole] = "date";
+    m_roleNames[VideoIdRole] = "videoId";
+    m_roleNames[ReplyIdRole] = "replyId";
+    m_roleNames[IndentRole] = "indent";
+    m_roleNames[LoadingRole] = "loading";
 #ifndef QML_USER_INTERFACE
-    roles[ArtistAvatarRole] = "artistAvatar";
-    roles[AvatarPressedRole] = "avatarPressed";
-    roles[LoaderPressedRole] = "loaderPressed";
+    m_roleNames[ArtistAvatarRole] = "artistAvatar";
+    m_roleNames[AvatarPressedRole] = "avatarPressed";
+    m_roleNames[LoaderPressedRole] = "loaderPressed";
 #endif
-    this->setRoleNames(roles);
+    m_roleNames[ServiceRole] = "service";
+#if QT_VERSION < 0x050000
+    this->setRoleNames(m_roleNames);
+#endif
+
 #ifndef QML_USER_INTERFACE
     this->connect(m_cache, SIGNAL(thumbnailReady()), this, SLOT(onThumbnailReady()));
 #endif
@@ -41,6 +44,12 @@ AbstractCommentListModel::~AbstractCommentListModel() {
 #endif
 }
 
+#if QT_VERSION >= 0x050000
+QHash<int, QByteArray> AbstractCommentListModel::roleNames() const {
+    return m_roleNames;
+}
+#endif
+
 void AbstractCommentListModel::clear() {
     this->beginResetModel();
     m_list.clear();
@@ -83,6 +92,8 @@ QVariant AbstractCommentListModel::data(const QModelIndex &index, int role) cons
         return m_list.at(index.row()).data()->indent();
     case LoadingRole:
         return m_list.at(index.row()).data()->loading();
+    case ServiceRole:
+        return m_list.at(index.row()).data()->service();
     default:
         return QVariant();
     }
