@@ -69,6 +69,10 @@ public slots:
     void clear();
     void selectAll();
     void selectNone();
+    void selectRow(int row);
+    void selectRows(const QList<int> &rows);
+    void deselectRow(int row);
+    void deselectRows(const QList<int> &rows);
     void toggleSelected(int row);
     void insertVideo(int row, QSharedPointer<VideoItem> video);
     void appendVideo(QSharedPointer<VideoItem> video);
