@@ -5,6 +5,9 @@
 #include <QNetworkReply>
 #include <QNetworkRequest>
 #include <QTimer>
+#if QT_VERSION >= 0x050000
+#include <QUrlQuery>
+#endif
 
 using namespace QtJson;
 
@@ -47,7 +50,13 @@ void DailymotionCommentListModel::getComments(const QString &id) {
 
     this->setLoading(true);
     QUrl feed(this->feed());
+#if QT_VERSION >= 0x050000
+    QUrlQuery query(feed);
+    query.addQueryItem("fields", DAILYMOTION_COMMENT_FIELDS);
+    feed.setQuery(query);
+#else
     feed.addQueryItem("fields", DAILYMOTION_COMMENT_FIELDS);
+#endif
     QNetworkReply *reply = Dailymotion::instance()->createReply(feed, this->offset());
     reply->setParent(this);
     this->connect(reply, SIGNAL(finished()), this, SLOT(addComments()));
