@@ -17,7 +17,7 @@ HomescreenModel::HomescreenModel(QObject *parent) :
     m_list.append(QPair<QString, QString>(tr("Transfers"), "images/transfers.png"));
     m_list.append(QPair<QString, QString>(tr("Archive"), "images/archive.png"));
     m_list.append(QPair<QString, QString>(tr("Accounts"), "images/accounts.png"));
-#ifdef Q_WS_SAILFISH
+#ifdef SAILFISH_OS
     m_list.append(QPair<QString, QString>(tr("Settings"), "images/settings.png"));
     m_list.append(QPair<QString, QString>(tr("About"), "images/about.png"));
 #endif
