@@ -23,12 +23,11 @@
 #endif
 #endif
 
-Session* sessionInstance = 0;
+Session* Session::self = 0;
 
 Session::Session(QObject *parent) :
     QObject(parent),
     m_nam(new NetworkAccessManager(this)),
-    m_jar(new CookieJar(m_nam)),
     m_settings(new Settings(this)),
     m_database(new Database(this)),
     m_launcher(new VideoLauncher(this)),
@@ -51,11 +50,10 @@ Session::Session(QObject *parent) :
   #endif
   #endif
 {
-    if (!sessionInstance) {
-        sessionInstance = this;
+    if (!self) {
+        self = this;
     }
 
-    this->networkAccessManager()->setCookieJar(m_jar);
     this->onMediaPlayerChanged(m_settings->mediaPlayer());
 
     this->connect(m_database, SIGNAL(gotDailymotionAccount(QString,QString,QString)), m_dailymotion, SLOT(setAccount(QString,QString,QString)));
@@ -86,11 +84,11 @@ Session::Session(QObject *parent) :
     this->connect(m_dailymotion, SIGNAL(gotVideosFromIds(QList< QSharedPointer<VideoItem> >)), m_sharing, SLOT(addVideosToCache(QList< QSharedPointer<VideoItem> >)));
     this->connect(m_vimeo, SIGNAL(gotVideosFromIds(QList< QSharedPointer<VideoItem> >)), m_sharing, SLOT(addVideosToCache(QList< QSharedPointer<VideoItem> >)));
 
-    this->connect(m_youtube, SIGNAL(signedIn(QString,QString,QString)), m_jar, SLOT(clearCookies()));
-    this->connect(m_dailymotion, SIGNAL(signedIn(QString,QString,QString)), m_jar, SLOT(clearCookies()));
-    this->connect(m_vimeo, SIGNAL(signedIn(QString,QString,QString)), m_jar, SLOT(clearCookies()));
-    this->connect(m_sharing, SIGNAL(signedInToFacebook(QString)), m_jar, SLOT(clearCookies()));
-    this->connect(m_sharing, SIGNAL(signedInToTwitter(QString,QString)), m_jar, SLOT(clearCookies()));
+    this->connect(m_youtube, SIGNAL(signedIn(QString,QString,QString)), m_nam->cookieJar(), SLOT(clearCookies()));
+    this->connect(m_dailymotion, SIGNAL(signedIn(QString,QString,QString)), m_nam->cookieJar(), SLOT(clearCookies()));
+    this->connect(m_vimeo, SIGNAL(signedIn(QString,QString,QString)), m_nam->cookieJar(), SLOT(clearCookies()));
+    this->connect(m_sharing, SIGNAL(signedInToFacebook(QString)), m_nam->cookieJar(), SLOT(clearCookies()));
+    this->connect(m_sharing, SIGNAL(signedInToTwitter(QString,QString)), m_nam->cookieJar(), SLOT(clearCookies()));
 
     this->connect(m_database, SIGNAL(alert(QString)), m_notifications, SLOT(onAlert(QString)));
     this->connect(m_database, SIGNAL(error(QString)), m_notifications, SLOT(onError(QString)));
@@ -155,14 +153,13 @@ Session::Session(QObject *parent) :
     m_dailymotion->setNetworkAccessManager(this->networkAccessManager());
     m_vimeo->setNetworkAccessManager(this->networkAccessManager());
     m_sharing->setNetworkAccessManager(this->networkAccessManager());
-    m_transferManager->setNetworkAccessManager(this->networkAccessManager());
 #ifdef IN_APP_UPDATES
     m_updateManager->setNetworkAccessManager(this->networkAccessManager());
 #endif
     m_settings->restoreSettings();
     m_database->restoreAccounts();
 #ifndef QML_USER_INTERFACE
-    m_transferManager->restoreStoredDownloads();
+    m_transferManager->restoreStoredTransfers();
 #endif
 }
 
@@ -174,7 +171,7 @@ Session::~Session() {
 }
 
 Session* Session::instance() {
-    return sessionInstance;
+    return !self ? new Session : self;
 }
 
 void Session::onMediaPlayerChanged(const QString &player) {
