@@ -233,8 +233,11 @@ void UrlGrabber::addYouTubeDecryptionFunctionToCache() {
 
     QString response(reply->readAll());
     QString funcName = response.section("signature=", 1, 1).section('(', 0, 0);
-    response = QString("function %1%2").arg(funcName).arg(response.section("function " + funcName, 1, 1).section(";function", 0, 0));
-    youtubeDecryptionEngine->evaluate(response);
+    QString var = response.section("function " + funcName, 0, 0).section(";var", -1);
+    QString funcBody = QString("function %2%3").arg(funcName).arg(response.section("function " + funcName, 1, 1).section(";function", 0, 0));
+    QString js = QString("var%1 %2").arg(var).arg(funcBody);
+    qDebug() << "Found decryption function:" << js;
+    youtubeDecryptionEngine->evaluate(js);
 
     QScriptValue global = youtubeDecryptionEngine->globalObject();
     QScriptValue decryptionFunction = global.property(funcName);
@@ -244,6 +247,7 @@ void UrlGrabber::addYouTubeDecryptionFunctionToCache() {
         emit youtubeDecryptionFunctionReady(decryptionFunction);
     }
     else {
+        this->setBusy(false);
         emit error(tr("Unable to decrypt video signature"));
         this->disconnect(this, SIGNAL(youtubeDecryptionFunctionReady(QScriptValue)), 0, 0);
     }
@@ -520,6 +524,7 @@ void UrlGrabber::parseYouTubeVideoPage(QScriptValue decryptionFunction, QString
         emit error(tr("Unable to retrieve video. Access may be restricted"));
     }
     else {
+        qDebug() << videoUrl;
         emit gotVideoUrl(videoUrl, m_format);
     }
 }
