@@ -10,18 +10,20 @@ VimeoUserGroupListModel::VimeoUserGroupListModel(QObject *parent) :
     ,m_cache(new ThumbnailCache)
   #endif
 {
-    QHash<int, QByteArray> roles;
-    roles[IdRole] = "id";
-    roles[TitleRole] = "title";
-    roles[ArtistRole] = "artist";
-    roles[DateRole] = "date";
-    roles[VideoCountRole] = "videoCount";
+    m_roleNames[IdRole] = "id";
+    m_roleNames[TitleRole] = "title";
+    m_roleNames[ArtistRole] = "artist";
+    m_roleNames[DateRole] = "date";
+    m_roleNames[VideoCountRole] = "videoCount";
 #ifndef QML_USER_INTERFACE
-    roles[ThumbnailRole] = "thumbnail";
+    m_roleNames[ThumbnailRole] = "thumbnail";
 #endif
-    roles[ThumbnailUrlRole] = "thumbnailUrl";
-    roles[DescriptionRole] = "description";
-    this->setRoleNames(roles);
+    m_roleNames[ThumbnailUrlRole] = "thumbnailUrl";
+    m_roleNames[DescriptionRole] = "description";
+#if QT_VERSION < 0x050000
+    this->setRoleNames(m_roleNames);
+#endif
+
 #ifndef QML_USER_INTERFACE
     this->connect(m_cache, SIGNAL(thumbnailReady()), this, SLOT(onThumbnailReady()));
 #endif
@@ -40,6 +42,12 @@ VimeoUserGroupListModel::~VimeoUserGroupListModel() {
 #endif
 }
 
+#if QT_VERSION >= 0x050000
+QHash<int, QByteArray> VimeoUserGroupListModel::roleNames() const {
+    return m_roleNames;
+}
+#endif
+
 void VimeoUserGroupListModel::onGroupAdded(int row) {
     this->beginInsertRows(QModelIndex(), row, row);
     this->endInsertRows();
