@@ -1,5 +1,6 @@
 #include "commentdelegate.h"
 #include "../base/abstractcommentlistmodel.h"
+#include "../base/utils.h"
 #include <QApplication>
 #include <QMouseEvent>
 #include <QPainter>
@@ -13,18 +14,16 @@ CommentDelegate::CommentDelegate(QObject *parent) :
 void CommentDelegate::paint(QPainter *painter, const QStyleOptionViewItem &option, const QModelIndex &index) const {
     painter->save();
 
+    Utils::drawBorderImage(painter, option.rect, QImage("/etc/hildon/theme/images/ContactsAppletBubble.png"), 60, 30, 30, 30);
+
     int indent = index.data(AbstractCommentListModel::IndentRole).toInt();
     bool avatarPressed = index.data(AbstractCommentListModel::AvatarPressedRole).toBool();
-    bool loaderPressed = index.data(AbstractCommentListModel::LoaderPressedRole).toBool();
-
-    if (((option.state) & (QStyle::State_Selected)) && (!avatarPressed) && (!loaderPressed)) {
-        painter->drawImage(option.rect, QImage("/etc/hildon/theme/images/TouchListBackgroundPressed.png"));
-    }
+//    bool loaderPressed = index.data(AbstractCommentListModel::LoaderPressedRole).toBool();
 
     QRect backgroundRect = option.rect;
-    backgroundRect.setLeft(backgroundRect.left() + 5 + (indent * 20));
-    backgroundRect.setRight(backgroundRect.right() - 5);
-    backgroundRect.setTop(backgroundRect.top() + 5);
+    backgroundRect.setLeft(backgroundRect.left() + 24 + (indent * 20));
+    backgroundRect.setRight(backgroundRect.right() - 16);
+    backgroundRect.setTop(backgroundRect.top() + 16);
 
     QRect artistRect = backgroundRect;
     artistRect.setLeft(artistRect.left() + 60);
@@ -33,14 +32,13 @@ void CommentDelegate::paint(QPainter *painter, const QStyleOptionViewItem &optio
     QFont newFont;
     newFont.setPixelSize(18);
     painter->setFont(newFont);
+    painter->setPen(QMaemo5Style::standardColor("ReversedTextColor"));
 
     QString artistText = QString("%1 - %2").arg(index.data(AbstractCommentListModel::ArtistRole).toString(), index.data(AbstractCommentListModel::DateRole).toString());
 
     painter->drawText(artistRect, Qt::AlignTop | Qt::TextWordWrap, artistText);
 
     painter->restore();
-    painter->save();
-    painter->setPen(QMaemo5Style::standardColor("SecondaryTextColor"));
 
     if ((option.state) & (QStyle::State_Selected) && (avatarPressed)) {
         painter->setOpacity(0.5);
@@ -54,18 +52,20 @@ void CommentDelegate::paint(QPainter *painter, const QStyleOptionViewItem &optio
 
     painter->drawRect(backgroundRect.left(), backgroundRect.top(), 50, 50);
 
-    QString id = index.data(AbstractCommentListModel::IdRole).toString();
-    QString replyId = index.data(AbstractCommentListModel::ReplyIdRole).toString();
-
-    if ((!replyId.isEmpty()) && (replyId != id) && (indent == 0)) {
-        if ((option.state) & (QStyle::State_Selected) && (loaderPressed)) {
-            painter->setOpacity(0.5);
-        }
-
-        painter->drawImage(backgroundRect.right() - 43, backgroundRect.top() - 10, QImage("/usr/share/icons/hicolor/48x48/hildon/rss_reader_move_up.png"));
-    }
-
+//    QString id = index.data(AbstractCommentListModel::IdRole).toString();
+//    QString replyId = index.data(AbstractCommentListModel::ReplyIdRole).toString();
+//
+//    if ((!replyId.isEmpty()) && (replyId != id) && (indent == 0)) {
+//        if ((option.state) & (QStyle::State_Selected) && (loaderPressed)) {
+//            painter->setOpacity(0.5);
+//        }
+//
+//        painter->drawImage(backgroundRect.right() - 43, backgroundRect.top() - 10, QImage("/usr/share/icons/hicolor/48x48/hildon/rss_reader_move_up.png"));
+//    }
+//
     painter->setOpacity(1);
+    painter->save();
+    painter->setPen(QMaemo5Style::standardColor("ReversedTextColor"));
 
     QRect bodyRect = backgroundRect;
     bodyRect.setTop(bodyRect.top() + 55);
@@ -87,15 +87,15 @@ bool CommentDelegate::editorEvent(QEvent *event, QAbstractItemModel *model, cons
         if (avatarRect.contains(mouse->pos())) {
             model->setData(index, index.row(), AbstractCommentListModel::AvatarPressedRole);
         }
-        else if (!index.data(AbstractCommentListModel::LoadingRole).toBool()) {
-            QRect arrowRect = option.rect;
-            arrowRect.setLeft(arrowRect.right() - 53);
-            arrowRect.setSize(QSize(48, 48));
-
-            if (arrowRect.contains(mouse->pos())) {
-                model->setData(index, index.row(), AbstractCommentListModel::LoaderPressedRole);
-            }
-        }
+//        else if (!index.data(AbstractCommentListModel::LoadingRole).toBool()) {
+//            QRect arrowRect = option.rect;
+//            arrowRect.setLeft(arrowRect.right() - 53);
+//            arrowRect.setSize(QSize(48, 48));
+//
+//            if (arrowRect.contains(mouse->pos())) {
+//                model->setData(index, index.row(), AbstractCommentListModel::LoaderPressedRole);
+//           }
+//        }
 
         return true;
     }
@@ -113,18 +113,18 @@ bool CommentDelegate::editorEvent(QEvent *event, QAbstractItemModel *model, cons
                 emit showUserChannel(index);
             }
         }
-        else if ((index.data(AbstractCommentListModel::LoaderPressedRole).toBool()) && (!index.data(AbstractCommentListModel::LoadingRole).toBool())) {
-            QRect arrowRect = option.rect;
-            arrowRect.setLeft(arrowRect.right() - 48);
-            arrowRect.setSize(QSize(48, 48));
-
-            if (arrowRect.contains(mouse->pos())) {
-                emit getInitialComment(index.row());
-            }
-        }
+//        else if ((index.data(AbstractCommentListModel::LoaderPressedRole).toBool()) && (!index.data(AbstractCommentListModel::LoadingRole).toBool())) {
+//            QRect arrowRect = option.rect;
+//            arrowRect.setLeft(arrowRect.right() - 48);
+//            arrowRect.setSize(QSize(48, 48));
+//
+//            if (arrowRect.contains(mouse->pos())) {
+//                emit getInitialComment(index.row());
+//            }
+//        }
 
         model->setData(index, -1, AbstractCommentListModel::AvatarPressedRole);
-        model->setData(index, -1, AbstractCommentListModel::LoaderPressedRole);
+//        model->setData(index, -1, AbstractCommentListModel::LoaderPressedRole);
 
         return true;
     }
