@@ -4,7 +4,6 @@
 #include "abstracttab.h"
 #include "../base/playlistitem.h"
 
-class Session;
 class ListView;
 class DailymotionPlaylistListModel;
 class QLabel;
@@ -16,8 +15,8 @@ class DailymotionPlaylistListTab : public AbstractTab
     Q_OBJECT
 
 public:
-    explicit DailymotionPlaylistListTab(Session *session, QWidget *parent = 0);
-    void setPlaylistFeed(const QString &feed);
+    explicit DailymotionPlaylistListTab(QWidget *parent = 0);
+    void setPlaylistFeed(const QUrl &feed);
 
 private:
     void setLandscapeLayout();
@@ -30,7 +29,6 @@ private slots:
     void showPlaylist(QSharedPointer<PlaylistItem> playlist);
 
 private:
-    Session *m_session;
     ListView *m_listView;
     DailymotionPlaylistListModel *m_model;
     QLabel *m_noResultsLabel;
