@@ -3,20 +3,20 @@
 
 #include "abstracttab.h"
 
-class Session;
 class DailymotionUserListModel;
 class ListView;
 class QLabel;
 class QGridLayout;
 class QAction;
 class QModelIndex;
+class QUrl;
 
 class DailymotionUserListTab : public AbstractTab
 {
     Q_OBJECT
 public:
-    explicit DailymotionUserListTab(Session *session, const QString &userId, QWidget *parent = 0);
-    void setFeed(const QString &feed);
+    explicit DailymotionUserListTab(const QString &userId, QWidget *parent = 0);
+    void setFeed(const QUrl &feed);
 
 private:
     void setLandscapeLayout();
@@ -30,7 +30,6 @@ private slots:
     void showSubscriptionVideos();
 
 private:
-    Session *m_session;
     QString m_userId;
     DailymotionUserListModel *m_model;
     ListView *m_listView;
