@@ -18,9 +18,6 @@
 #include "dailymotionvideolistwindow.h"
 #include "youtubeplaylistlistwindow.h"
 #include "dailymotionplaylistlistwindow.h"
-#include "youtubevideoinfowindow.h"
-#include "dailymotionvideoinfowindow.h"
-#include "vimeovideoinfowindow.h"
 #include "youtubeuserlistwindow.h"
 #include "dailymotionuserlistwindow.h"
 #include "dailymotiongrouplistwindow.h"
@@ -30,6 +27,7 @@
 #include "socialvideolistwindow.h"
 #include "archivewindow.h"
 #include "navbutton.h"
+#include "resourceloader.h"
 #include "../base/feedurls.h"
 #include "../base/sharing.h"
 #include "../base/youtube.h"
@@ -76,7 +74,7 @@ HomeWindow::HomeWindow(QWidget *parent) :
     this->connect(YouTube::instance(), SIGNAL(requestToLinkGoogleAccount()), this, SLOT(showLinkGoogleAccountDialog()));
     this->connect(Sharing::instance(), SIGNAL(reauthenticateForFacebook()), this, SLOT(showFacebookAuthDialog()));
     this->connect(Sharing::instance(), SIGNAL(reauthenticateForTwitter()), this, SLOT(showTwitterAuthDialog()));
-    this->connect(ClipboardMonitor::instance(), SIGNAL(gotClipboardUrl(QString)), this, SLOT(display(QString)));
+    this->connect(ClipboardMonitor::instance(), SIGNAL(gotClipboardUrl(QString)), ResourceLoader::instance(), SLOT(display(QString)));
 
     this->onOrientationChanged();
 }
@@ -398,17 +396,18 @@ void HomeWindow::showSearchDialog() {
     dialog->open();
 
     this->connect(dialog, SIGNAL(search(QString)), this, SLOT(search(QString)));
-    this->connect(dialog, SIGNAL(goToVideo(QString)), this, SLOT(display(QString)));
 }
 
 void HomeWindow::search(const QString &query) {
-    this->search(query,
-                 Settings::instance()->searchSite(),
-                 Settings::instance()->searchType(),
-                 Settings::instance()->searchOrder(),
-                 Settings::instance()->searchTime(),
-                 Settings::instance()->searchDuration(),
-                 Settings::instance()->languageFilter());
+    if (!ResourceLoader::instance()->display(query, false)) {
+        this->search(query,
+                     Settings::instance()->searchSite(),
+                     Settings::instance()->searchType(),
+                     Settings::instance()->searchOrder(),
+                     Settings::instance()->searchTime(),
+                     Settings::instance()->searchDuration(),
+                     Settings::instance()->languageFilter());
+    }
 }
 
 void HomeWindow::search(const QString &query, Services::VideoService service, Queries::QueryType type, Queries::QueryOrder order, Queries::TimeFilter timeFilter, Queries::DurationFilter durationFilter, const QString &languageFilter) {
@@ -519,63 +518,6 @@ void HomeWindow::userSearch(const QString &query, Services::VideoService service
     }
 }
 
-void HomeWindow::display(const QStringList &urls) {
-    if (!urls.isEmpty()) {
-        this->display(urls.first());
-    }
-}
-
-void HomeWindow::display(const QString &url) {
-    WindowStack::instance()->unwindWindowStack();
-    this->activateWindow();
-
-    if (url.contains(QRegExp("youtube|youtu.be"))) {
-        YouTube::instance()->getFullVideo(url);
-        this->connect(YouTube::instance(), SIGNAL(gotVideo(QSharedPointer<VideoItem>)), this, SLOT(showYouTubeVideo(QSharedPointer<VideoItem>)));
-    }
-    else if (url.contains(QRegExp("dailymotion|dai.ly"))) {
-        Dailymotion::instance()->getFullVideo(url);
-        this->connect(Dailymotion::instance(), SIGNAL(gotVideo(QSharedPointer<VideoItem>)), this, SLOT(showDailymotionVideo(QSharedPointer<VideoItem>)));
-    }
-    else if (url.contains("vimeo")) {
-        Vimeo::instance()->getFullVideo(url);
-        this->connect(Vimeo::instance(), SIGNAL(gotVideo(QSharedPointer<VideoItem>)), this, SLOT(showVimeoVideo(QSharedPointer<VideoItem>)));
-    }
-}
-
-void HomeWindow::play(const QStringList &urls) {
-    if (!urls.isEmpty()) {
-        this->play(urls.first());
-    }
-}
-
-void HomeWindow::play(const QString &url) {
-    Q_UNUSED(url);
-
-    this->activateWindow();
-}
-
-void HomeWindow::showYouTubeVideo(QSharedPointer<VideoItem> video) {
-    YouTubeVideoInfoWindow *window = new YouTubeVideoInfoWindow(video, this);
-    window->show();
-
-    this->disconnect(YouTube::instance(), SIGNAL(gotVideo(QSharedPointer<VideoItem>)), this, SLOT(showYouTubeVideo(QSharedPointer<VideoItem>)));
-}
-
-void HomeWindow::showDailymotionVideo(QSharedPointer<VideoItem> video) {
-    DailymotionVideoInfoWindow *window = new DailymotionVideoInfoWindow(video, this);
-    window->show();
-
-    this->disconnect(Dailymotion::instance(), SIGNAL(gotVideo(QSharedPointer<VideoItem>)), this, SLOT(showDailymotionVideo(QSharedPointer<VideoItem>)));
-}
-
-void HomeWindow::showVimeoVideo(QSharedPointer<VideoItem> video) {
-    VimeoVideoInfoWindow *window = new VimeoVideoInfoWindow(video, this);
-    window->show();
-
-    this->disconnect(Vimeo::instance(), SIGNAL(gotVideo(QSharedPointer<VideoItem>)), this, SLOT(showVimeoVideo(QSharedPointer<VideoItem>)));
-}
-
 void HomeWindow::showPlaybackQueue() {
     PlaybackQueueWindow *window = new PlaybackQueueWindow(this);
     window->show();
