@@ -3,7 +3,6 @@
 
 #include "abstractdialog.h"
 
-class Settings;
 class QCheckBox;
 class QDialogButtonBox;
 class QScrollArea;
@@ -13,7 +12,7 @@ class SearchOptionsDialog : public AbstractDialog
 {
     Q_OBJECT
 public:
-    explicit SearchOptionsDialog(Settings *settings, QWidget *parent = 0);
+    explicit SearchOptionsDialog(QWidget *parent = 0);
 
 private slots:
     void saveSettings();
@@ -24,7 +23,6 @@ private:
     void setPortraitLayout();
 
 private:
-    Settings *m_settings;
     QCheckBox *m_serviceCheckbox;
     QCheckBox *m_typeCheckbox;
     QCheckBox *m_orderCheckbox;
