@@ -5,8 +5,10 @@
 
 class MediaPlayerSelector;
 class ConcurrentTransfersSelector;
+class ConnectionsSelector;
 class ScreenOrientationSelector;
 class LanguageSelector;
+class SubtitlesSelector;
 class PlaybackFormatDialog;
 class DownloadFormatDialog;
 class SearchOptionsDialog;
@@ -47,6 +49,7 @@ private:
     QCheckBox *m_safeSearchCheckbox;
     QCheckBox *m_eventFeedCheckbox;
     QCheckBox *m_clipboardCheckbox;
+    QCheckBox *m_subtitlesCheckbox;
     QPushButton *m_searchButton;
     QPushButton *m_playbackButton;
     QPushButton *m_downloadButton;
@@ -55,6 +58,8 @@ private:
     QString m_downloadPath;
     MediaPlayerSelector *m_mediaPlayerSelector;
     ConcurrentTransfersSelector *m_concurrentSelector;
+    ConnectionsSelector *m_connectionsSelector;
+    SubtitlesSelector *m_subtitlesSelector;
     ScreenOrientationSelector *m_orientationSelector;
     LanguageSelector *m_languageSelector;
     QLineEdit *m_mediaPlayerCommandEdit;
