@@ -26,9 +26,8 @@ private:
 private slots:
     void onItemClicked(const QModelIndex &index);
     void showContextMenu(const QPoint &pos);
-    void setTransferSaveAsAudio();
     void showPriorityDialog();
-    void setTransferPriority(Transfers::TransferPriority priority);
+    void setTransferPriority(Transfers::Priority priority);
     void pauseOrResumeTransfer();
     void cancelTransfer();
     void onCountChanged(int count);
@@ -38,10 +37,11 @@ private:
     ListView *m_listView;
     QLabel *m_noResultsLabel;
     QMenu *m_contextMenu;
-    QAction *m_saveAsAudioAction;
     QAction *m_priorityAction;
     QAction *m_pauseResumeAction;
     QAction *m_cancelAction;
+    QAction *m_startAction;
+    QAction *m_pauseAction;
 };
 
 #endif // TRANSFERLISTWINDOW_H
