@@ -14,14 +14,14 @@ class TransferPriorityDialog : public AbstractDialog
 
 public:
     explicit TransferPriorityDialog(QWidget *parent = 0);
-    Transfers::TransferPriority currentValue() const;
-    void setValue(Transfers::TransferPriority priority);
+    Transfers::Priority currentValue() const;
+    void setValue(Transfers::Priority priority);
 
 private slots:
     void onItemClicked(const QModelIndex &index);
     
 signals:
-    void valueChanged(Transfers::TransferPriority priority);
+    void valueChanged(Transfers::Priority priority);
 
 private:
     TransferPriorityModel *m_model;
