@@ -10,16 +10,17 @@ class QMaemo5ListPickSelector;
 class TransferPrioritySelector : public QMaemo5ValueButton
 {
     Q_OBJECT
+
 public:
     explicit TransferPrioritySelector(const QString &text, QWidget *parent = 0);
-    void setValue(Transfers::TransferPriority value);
-    Transfers::TransferPriority currentValue();
+    void setValue(Transfers::Priority value);
+    Transfers::Priority currentValue();
 
 private slots:
     void onSelected();
     
 signals:
-    void valueChanged(Transfers::TransferPriority value);
+    void valueChanged(Transfers::Priority value);
     
 private:
     TransferPriorityModel *m_model;
