@@ -28,16 +28,16 @@ private slots:
     void onLoadingChanged(bool loading);
     void onCountChanged(int count);
     void showCommentDialog(QSharedPointer<CommentItem> initialComment = QSharedPointer<CommentItem>());
-    void showContextMenu(const QPoint &pos);
-    void replyToComment();
+//    void showContextMenu(const QPoint &pos);
+//    void replyToComment();
     void showUserChannel(const QModelIndex &index);
     
 private:
     QSharedPointer<VideoItem> m_video;
     YouTubeCommentListModel *m_model;
     ListView *m_listView;
-    QMenu *m_contextMenu;
-    QAction *m_replyAction;
+//    QMenu *m_contextMenu;
+//    QAction *m_replyAction;
     QAction *m_commentAction;
     QLabel *m_noResultsLabel;
     QGridLayout *m_grid;
