@@ -16,7 +16,7 @@ class YouTubeVideoInfoWindow : public StackedWindow
     Q_OBJECT
 
 public:
-    explicit YouTubeVideoInfoWindow(Session *session, QSharedPointer<VideoItem> video, QWidget *parent);
+    explicit YouTubeVideoInfoWindow(QSharedPointer<VideoItem> video, QWidget *parent);
 
 private:
     void clearMenuActions();
