@@ -1,6 +1,6 @@
 #include "youtube.h"
 #include "../../cutetubeapp/src/base/json.h"
-#include "../../cutetubeapp/src/base/utils.h"
+#include "../../cutetubeapp/src/base/definitions.h"
 #include <QNetworkAccessManager>
 #include <QNetworkRequest>
 #include <QNetworkReply>
@@ -48,7 +48,7 @@ QNetworkReply* YouTube::createReply(QString feed, int offset) {
     qDebug() << url;
 
     QNetworkRequest request(url);
-    request.setRawHeader("User-Agent", QString("cuteTube/%1 (Qt)").arg(Utils::versionNumberString()).toUtf8());
+    request.setRawHeader("User-Agent", QString("cuteTube/%1 (Qt)").arg(VERSION_NUMBER).toUtf8());
     request.setRawHeader("X-Gdata-Key", "key=" + this->developerKey().toUtf8());
 
     return this->networkAccessManager()->get(request);
@@ -63,7 +63,7 @@ void YouTube::refreshAccessToken() {
                     "&grant_type=refresh_token");
 
     QNetworkRequest request(url);
-    request.setRawHeader("User-Agent", QString("cuteTube/%1 (Qt)").arg(Utils::versionNumberString()).toUtf8());
+    request.setRawHeader("User-Agent", QString("cuteTube/%1 (Qt)").arg(VERSION_NUMBER).toUtf8());
     request.setHeader(QNetworkRequest::ContentTypeHeader, "application/x-www-form-urlencoded");
     QNetworkReply *reply = this->networkAccessManager()->post(request, body);
     this->connect(reply, SIGNAL(finished()), this, SLOT(checkTokenRefresh()));
